# TableConfig

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the table | 
**description** | **str** | Optional description of the table | [optional] 
**fields** | [**list[FieldConfigRequest]**](FieldConfigRequest.md) | Array of field configurations for the table | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

